@@ -7,12 +7,18 @@ use Teng::Schema::Declare;
 
 use App::Koyomi::Job;
 
-use version; our $VERSION = 'v0.1.4';
+use version; our $VERSION = 'v0.2.0';
 
 table {
     name    'jobs';
     pk      'id';
-    columns @App::Koyomi::Job::FIELDS;
+    columns @App::Koyomi::Job::JOB_FIELDS;
+};
+
+table {
+    name    'job_times';
+    pk      'job_id';
+    columns @App::Koyomi::Job::TIME_FIELDS;
 };
 
 1;
